@@ -20,7 +20,7 @@
 #'     \item Stata (.dta), using \code{\link[haven]{read_dta}}. If \code{haven = FALSE}, \code{\link[foreign]{read.dta}} can be used.
 #'     \item SAS XPORT (.xpt), using \code{\link[foreign]{read.xport}}.
 #'     \item SPSS Portable Files (.por), using \code{\link[haven]{read_por}}.
-#'     \item Excel (.xls and .xlsx), using \code{\link[readxl]{read_excel}}. If \code{readxl = FALSE}, \code{\link[openxlsx]{read.xlsx}} can be used. Use \code{which} to specify a sheet number.
+#'     \item Excel (.xls and .xlsx), using \code{\link[readxl]{read_excel}}. Use \code{which} to specify a sheet number. For .xlsx files, it is possible to set \code{readxl = FALSE}, so that \code{\link[openxlsx]{read.xlsx}} can be used instead of readxl (the default).
 #'     \item R syntax object (.R), using \code{\link[base]{dget}}
 #'     \item Saved R objects (.RData,.rda), using \code{\link[base]{load}} for single-object .Rdata files. Use \code{which} to specify an object name for multi-object .Rdata files.
 #'     \item Serialized R objects (.rds), using \code{\link[base]{readRDS}}
@@ -47,6 +47,8 @@
 #' }
 #'
 #' \code{import} attempts to standardize the return value from the various import functions to the extent possible, thus providing a uniform data structure regardless of what import package or function is used. It achieves this by storing any optional variable-related attributes at the variable level (i.e., an attribute for \code{mtcars$mpg} is stored in \code{attributes(mtcars$mpg)} rather than \code{attributes(mtcars)}). If you would prefer these attributes to be stored at the data.frame-level (i.e., in \code{attributes(mtcars)}), see \code{\link{gather_attrs}}.
+#' 
+#' After importing metadata-rich file formats (e.g., from Stata or SPSS), it may be helpful to recode labelled variables to character or factor using \code{\link{characterize}} or \code{\link{factorize}} respectively.
 #'
 #' @note For csv and txt files with row names exported from \code{\link{export}}, it may be helpful to specify \code{row.names} as the column of the table which contain row names. See example below.
 #' @examples
@@ -77,7 +79,7 @@
 #' unlink("iris1.csv")
 #' unlink("iris2.csv")
 #'
-#' @seealso \code{\link{import_list}}, \code{\link{.import}}, \code{\link{gather_attrs}}, \code{\link{export}}, \code{\link{convert}}
+#' @seealso \code{\link{import_list}}, \code{\link{.import}}, \code{\link{characterize}}, \code{\link{gather_attrs}}, \code{\link{export}}, \code{\link{convert}}
 #' @importFrom tools file_ext file_path_sans_ext
 #' @importFrom stats na.omit setNames
 #' @importFrom utils installed.packages untar unzip tar zip type.convert capture.output
@@ -121,13 +123,24 @@ import <- function(file, format, setclass, which, ...) {
         x <- .import(file = file, which = which, ...)
     }
 
-    if (missing(setclass)) {
-        return(set_class(x))
+    a <- list(...)
+    if (missing(setclass) || is.null(setclass)) {
+        if ("data.table" %in% names(a) && isTRUE(a[["data.table"]])) {
+            return(set_class(x, class = "data.table"))
+        } else {
+            return(set_class(x, class = "data.frame"))
+        }
+    } else {
+        if ("data.table" %in% names(a) && isTRUE(a[["data.table"]])) {
+            if (setclass != "data.table") {
+                warning(sprintf("'data.table = TRUE' argument overruled. Using setclass = '%s'", setclass))
+                return(set_class(x, class = setclass))
+            } else {
+                return(set_class(x, class = "data.table"))
+            }
+        } else {
+            return(set_class(x, class = setclass))
+        }
     }
 
-    a <- list(...)
-    if ("data.table" %in% names(a) && isTRUE(a[["data.table"]])) {
-        setclass <- "data.table"
-    }
-    return(set_class(x, class = setclass))
 }
