@@ -1,8 +1,10 @@
-context("Excel imports/exports")
+context("Excel (xlsx) imports/exports")
 require("datasets")
 
 test_that("Export to Excel (.xlsx)", {
     expect_true(export(iris, "iris.xlsx") %in% dir())
+    expect_true(export(iris, "iris.xlsx", overwrite = FALSE) %in% dir())
+    expect_true(export(mtcars, "iris.xlsx", which = 2) %in% dir())
 })
 
 test_that("Import from Excel (.xlsx)", {
